==> json-schema-for-humans-0.26.0.tar.gz: json-schema-for-humans-0.26.0/tests/generate_recursive_test.py <==
import pytest

from tests.test_utils import generate_case
from tests.html_schema_doc_asserts import assert_descriptions, assert_ref_link, get_ref_link


@pytest.mark.parametrize("link_to_reused_ref", [True, False])
def test_recursive(link_to_reused_ref: bool) -> None:
    """Test a schema having a recursive definition.

    Even if `link_to_reused_ref` is False, a reference will be generated to avoid a RecursionError
    """
    soup = generate_case("recursive", link_to_reused_ref=link_to_reused_ref)

    assert_descriptions(soup, ["A human being", "The children they had", "A human being"])

    assert_ref_link(soup, "#person", "Same definition as person")


def test_recursive_array() -> None:
    """Test a schema having a recursive definition pointing to array items"""
    soup = generate_case("recursive_array", link_to_reused_ref=True)

    assert_descriptions(soup, ["A list of people", "A human being", "The children they had", "A human being"])

    assert_ref_link(soup, "#person_items", "Same definition as person")


@pytest.mark.parametrize("link_to_reused_ref", [True, False])
def test_recursive_two_files(link_to_reused_ref: bool) -> None:
    """Test rendering a schema with a recursive definition with the same name, but in another file"""
    soup = generate_case("recursive_two_files", link_to_reused_ref=link_to_reused_ref)

    assert_descriptions(
        soup,
        [
            "A human being",
            "The children they had",
            "Person definition from second file. Not the same!",
            "Person definition from second file. Not the same!",
        ],
    )

    if link_to_reused_ref:
        assert_ref_link(soup, "#person_siblings", "Same definition as siblings")
    else:
        assert not get_ref_link(soup, "#person_siblings")

==> json-schema-for-humans-0.27.0.tar.gz: json-schema-for-humans-0.27.0/tests/generate_recursive_test.py <==
import pytest

from generate import GenerationConfiguration
from tests.test_utils import generate_case
from tests.html_schema_doc_asserts import assert_descriptions, assert_ref_link, get_ref_link


@pytest.mark.parametrize("link_to_reused_ref", [True, False])
def test_recursive(link_to_reused_ref: bool) -> None:
    """Test a schema having a recursive definition.

    Even if `link_to_reused_ref` is False, a reference will be generated to avoid a RecursionError
    """
    soup = generate_case("recursive", GenerationConfiguration(link_to_reused_ref=link_to_reused_ref))

    assert_descriptions(soup, ["A human being", "The children they had", "A human being"])

    assert_ref_link(soup, "#person", "Same definition as person")


def test_recursive_array() -> None:
    """Test a schema having a recursive definition pointing to array items"""
    soup = generate_case("recursive_array", GenerationConfiguration(link_to_reused_ref=True))

    assert_descriptions(soup, ["A list of people", "A human being", "The children they had", "A human being"])

    assert_ref_link(soup, "#person_items", "Same definition as person")


@pytest.mark.parametrize("link_to_reused_ref", [True, False])
def test_recursive_two_files(link_to_reused_ref: bool) -> None:
    """Test rendering a schema with a recursive definition with the same name, but in another file"""
    soup = generate_case("recursive_two_files", GenerationConfiguration(link_to_reused_ref=link_to_reused_ref))

    assert_descriptions(
        soup,
        [
            "A human being",
            "The children they had",
            "Person definition from second file. Not the same!",
            "Person definition from second file. Not the same!",
        ],
    )

    if link_to_reused_ref:
        assert_ref_link(soup, "#person_siblings", "Same definition as siblings")
    else:
        assert not get_ref_link(soup, "#person_siblings")
